@@ -82,7 +82,6 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 
 	}
 
-	
 	private Grid<TabResource> grid;
 	private ResourceBundle res;
 	private Menu contextMenu;
@@ -105,7 +104,7 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 		}
 		try {
 			buildPanel();
-					
+
 		} catch (Throwable e) {
 			Log.debug("Error building panel:" + e.getMessage());
 			e.printStackTrace();
@@ -132,10 +131,10 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 		IdentityValueProvider<TabResource> identity = new IdentityValueProvider<TabResource>();
 		final CheckBoxSelectionModel<TabResource> sm = new CheckBoxSelectionModel<TabResource>(
 				identity);
-		
+
 		TabResourcesProperties properties = GWT
 				.create(TabResourcesProperties.class);
-		
+
 		final ExtendedListStore<TabResource> store = new ExtendedListStore<TabResource>(
 				properties.id());
 
@@ -160,37 +159,28 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 
 		store.setEnableFilters(true);
 
-		
-		
-
 		ColumnConfig<TabResource, String> nameColumn = new ColumnConfig<TabResource, String>(
 				properties.name(), 90, "Name");
-		
-		
+
 		/*
-		nameColumn.setCell(
-		new AbstractCell<String>() {
+		 * nameColumn.setCell( new AbstractCell<String>() {
+		 * 
+		 * @Override public void render(Context context, String value,
+		 * SafeHtmlBuilder sb) { TabResource
+		 * tabResource=store.get(context.getIndex());
+		 * 
+		 * final NameTooltipTemplates nameToolTipTemplates = GWT
+		 * .create(NameTooltipTemplates.class); String valueSafe=""; String
+		 * descriptionSafe="";
+		 * 
+		 * if(value!=null){ valueSafe=SafeHtmlUtils.htmlEscape(value); }
+		 * if(tabResource!=null && tabResource.getAgency()!=null){
+		 * descriptionSafe=SafeHtmlUtils.htmlEscape(tabResource.getAgency()); }
+		 * sb.append(nameToolTipTemplates.format(valueSafe, descriptionSafe));
+		 * 
+		 * } });
+		 */
 
-			@Override
-			public void render(Context context, String value, SafeHtmlBuilder sb) {
-				TabResource tabResource=store.get(context.getIndex());
-				
-				final NameTooltipTemplates nameToolTipTemplates = GWT
-						.create(NameTooltipTemplates.class);
-				String valueSafe="";
-				String descriptionSafe="";
-				
-				if(value!=null){		
-						valueSafe=SafeHtmlUtils.htmlEscape(value);
-				}
-				if(tabResource!=null && tabResource.getAgency()!=null){
-					descriptionSafe=SafeHtmlUtils.htmlEscape(tabResource.getAgency());
-				}
-				sb.append(nameToolTipTemplates.format(valueSafe, descriptionSafe));
-
-			}
-		});*/
-		
 		ColumnConfig<TabResource, String> typeColumn = new ColumnConfig<TabResource, String>(
 				properties.tabResourceType(), 30, "Type");
 		ColumnConfig<TabResource, String> tableTypeNameColumn = new ColumnConfig<TabResource, String>(
@@ -217,14 +207,14 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 
 				} else {
 					sb.appendHtmlConstant("<img style='margin:auto;padding:auto;display:block;' src='"
-							+ ResourceBundleTDOpen.INSTANCE.lockOpen().getSafeUri()
-									.asString() + "' alt='true'>");
+							+ ResourceBundleTDOpen.INSTANCE.lockOpen()
+									.getSafeUri().asString() + "' alt='true'>");
 				}
 
 			}
 		});
-		
-		List<ColumnConfig<TabResource, ?>> columns=new ArrayList<ColumnConfig<TabResource,?>>();
+
+		List<ColumnConfig<TabResource, ?>> columns = new ArrayList<ColumnConfig<TabResource, ?>>();
 		columns.add(nameColumn);
 		columns.add(typeColumn);
 		columns.add(tableTypeNameColumn);
@@ -232,11 +222,9 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 		columns.add(ownerColumn);
 		columns.add(agencyColumn);
 		columns.add(dateColumn);
-		
+
 		ColumnModel<TabResource> cm = new ColumnModel<TabResource>(columns);
 
-		
-		
 		RpcProxy<ListLoadConfig, ListLoadResult<TabResource>> proxy = new RpcProxy<ListLoadConfig, ListLoadResult<TabResource>>() {
 
 			public void load(ListLoadConfig loadConfig,
@@ -262,9 +250,6 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 				});
 			}
 		};
-		
-	
-		
 
 		sm.setSelectionMode(SelectionMode.SINGLE);
 		grid.setLoader(loader);
@@ -337,6 +322,71 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 		});
 		contextMenu.add(deleteTRItem);
 
+		MenuItem infoItem = new MenuItem();
+		infoItem.setText("Info");
+		infoItem.setIcon(ResourceBundleTDOpen.INSTANCE.information());
+		infoItem.addSelectionHandler(new SelectionHandler<Item>() {
+
+			@Override
+			public void onSelection(SelectionEvent<Item> event) {
+				if (grid != null) {
+					TabResource tabResource = getSelectedItem();
+					requestInfo(tabResource);
+				}
+
+			}
+		});
+
+		contextMenu.add(infoItem);
+
+	}
+
+	protected void openInfoDialog(TabResource tabResource) {
+		final TabResourceInfoDialog tabResourceInfoDialog = new TabResourceInfoDialog(
+				tabResource);
+		tabResourceInfoDialog.show();
+	}
+
+	protected void requestInfo(TabResource tabResource) {
+		if(tabResource.isLocked()){
+			UtilsGXT3.alert("Attention", "Tabular Resource is locked no info available!");
+			return;
+		}
+	
+		TDGWTServiceAsync.INSTANCE.getTabResourceInformation(
+				tabResource.getTrId(), new AsyncCallback<TabResource>() {
+
+					public void onSuccess(TabResource result) {
+						Log.info("Retrived TR: " + result.getTrId());
+						openInfoDialog(result);
+					}
+
+					public void onFailure(Throwable caught) {
+						if (caught instanceof TDGWTSessionExpiredException) {
+							parent.getEventBus()
+									.fireEvent(
+											new SessionExpiredEvent(
+													SessionExpiredType.EXPIREDONSERVER));
+						} else {
+							if (caught instanceof TDGWTIsLockedException) {
+								Log.error("Tabular Resource is Locked: "
+										+ caught.getLocalizedMessage());
+								parent.showErrorAndHide("Error",
+										caught.getLocalizedMessage(), "", caught);
+								
+								
+							} else {
+								Log.error("Error: "
+										+ caught.getLocalizedMessage());
+								parent.showErrorAndHide("Error",
+										caught.getLocalizedMessage(), "", caught);
+								
+							}
+
+						}
+					}
+
+				});
 	}
 
 	protected boolean select(TabResource item, String searchTerm) {
@@ -377,9 +427,8 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 						} else {
 							Log.error("Error retrieving tabular resource: "
 									+ caught.getLocalizedMessage());
-							parent.showErrorAndHide(
-									"Error",
-									caught.getLocalizedMessage(),"", caught);
+							parent.showErrorAndHide("Error",
+									caught.getLocalizedMessage(), "", caught);
 						}
 						callback.onFailure(caught);
 					}
@@ -389,9 +438,9 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 								+ " TabularResources");
 						ArrayList<TabResource> avaibles = new ArrayList<TabResource>();
 						for (TabResource tResource : result) {
-							//if (!tResource.isLocked()) {
+							// if (!tResource.isLocked()) {
 							avaibles.add(tResource);
-							//}
+							// }
 						}
 
 						/*
@@ -486,7 +535,7 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 								Log.error("Error on delete TabResource: "
 										+ caught.getLocalizedMessage());
 								UtilsGXT3.alert("Error",
-												caught.getLocalizedMessage());
+										caught.getLocalizedMessage());
 							}
 						}
 					}
